can_write_study: Check if a study folder can be written to

View source: R/lock.R

can_write_studyR Documentation

Check if a study folder can be written to

Description

Returns TRUE if the folder is not locked; FALSE with a warning otherwise.

Usage

can_write_study(study_path, operation = "write to study folder")

Arguments

study_path

Path to the study folder

operation

Description of the operation being attempted

Value

Logical indicating if the operation can proceed


clinTrialData documentation built on March 3, 2026, 5:07 p.m.