connect_to_source: Connect to Data Source

View source: R/connections.R

connect_to_sourceR Documentation

Connect to Data Source

Description

Generic function to connect to any data source by scanning its directory structure and generating the connector configuration dynamically. Wraps all filesystem connectors with lock protection.

Resolution order:

  1. User cache (downloaded via download_study())

  2. Package-bundled data (⁠inst/exampledata/⁠)

Usage

connect_to_source(source_name)

Arguments

source_name

Name of the data source (e.g., "cdisc_pilot")

Value

A connectors object


clinTrialData documentation built on March 3, 2026, 5:07 p.m.