dot-load_stale_studies: Load a stale study listing and refresh the 'cached' column

.load_stale_studiesR Documentation

Load a stale study listing and refresh the cached column

Description

Load a stale study listing and refresh the cached column

Usage

.load_stale_studies(reason)

Arguments

reason

Character string describing why the fallback is needed.

Value

A data frame, or NULL if no cache exists.


clinTrialData documentation built on March 3, 2026, 5:07 p.m.