| generate_connector_config | R Documentation |
Scans a data source directory and generates a connector configuration list dynamically based on the available parquet files.
generate_connector_config(source_path)
source_path |
Path to the data source directory |
A list suitable for passing to connector::connect()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.