is_study_locked: Check if a study folder is locked

View source: R/lock.R

is_study_lockedR Documentation

Check if a study folder is locked

Description

Checks whether a study path is locked in the current session, indicating that the data should not be overwritten.

Usage

is_study_locked(study_path)

Arguments

study_path

Path to the study folder

Value

Logical indicating if the folder is locked


clinTrialData documentation built on March 3, 2026, 5:07 p.m.