unlock_study: Unlock a study folder

View source: R/lock.R

unlock_studyR Documentation

Unlock a study folder

Description

Removes the in-memory lock on a study path, allowing write operations for the remainder of the current R session. On Unix-like systems, also restores write permissions on cached study directories.

Usage

unlock_study(study_path)

Arguments

study_path

Path to the study folder

Value

Logical indicating success, invisibly


clinTrialData documentation built on March 3, 2026, 5:07 p.m.