Generic connection function that allows access to any data source in the package. Data sources are automatically discovered by scanning the package's example data directory structure.
Arguments
- source
Character string specifying the data source. Use
list_data_sources()to see all available options.
Examples
# \donttest{
if (interactive()) {
# Connect to CDISC Pilot data
db <- connect_clinical_data("cdisc_pilot")
# List available datasets
db$adam$list_content_cnt()
# Read a dataset (requires the arrow package)
if (requireNamespace("arrow", quietly = TRUE)) {
adsl <- db$adam$read_cnt("adsl")
}
# List available sources
list_data_sources()
}
# }