| connect_clinical_data | R Documentation |
Generic connection function that allows access to any data source in the package. Data sources are automatically discovered by scanning the package's example data directory structure.
connect_clinical_data(source = "cdisc_pilot")
source |
Character string specifying the data source.
Use |
A connectors object
# Connect to CDISC Pilot data
db <- connect_clinical_data("cdisc_pilot")
# List available datasets
db$adam$list_content_cnt()
# Read a dataset
adsl <- db$adam$read_cnt("adsl")
# List available sources
list_data_sources()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.