| connect_to_source | R Documentation |
Generic function to connect to any data source by scanning its directory structure and generating the connector configuration dynamically. Wraps all filesystem connectors with lock protection.
Resolution order:
User cache (downloaded via download_study())
Package-bundled data (inst/exampledata/)
connect_to_source(source_name)
source_name |
Name of the data source (e.g., "cdisc_pilot") |
A connectors object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.