| is_study_locked | R Documentation |
Checks whether a study path is locked in the current session, indicating that the data should not be overwritten.
is_study_locked(study_path)
study_path |
Path to the study folder |
Logical indicating if the folder is locked
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.