Returns information about all clinical datasets available locally –
both datasets bundled with the package and any datasets previously
downloaded via download_study(). The location column indicates
whether a dataset is "bundled" (shipped with the package) or
"cached" (downloaded to the user cache directory).
To see datasets available for download from GitHub, use
list_available_studies().
Value
A data frame with columns:
- source
Dataset name (pass to
connect_clinical_data())- description
Human-readable study description
- domains
Comma-separated list of available data domains (e.g.
"adam, sdtm")- format
Storage format (
"parquet")- location
Either
"bundled"or"cached"