| list_data_sources | R Documentation |
Returns information about all clinical datasets available locally –
both datasets bundled with the package and any datasets previously
downloaded via download_study(). The location column indicates
whether a dataset is "bundled" (shipped with the package) or
"cached" (downloaded to the user cache directory).
To see datasets available for download from GitHub, use
list_available_studies().
list_data_sources()
A data frame with columns:
Dataset name (pass to connect_clinical_data())
Human-readable study description
Comma-separated list of available data domains
(e.g. "adam, sdtm")
Storage format ("parquet")
Either "bundled" or "cached"
list_data_sources()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.