| unlock_study | R Documentation |
Removes the in-memory lock on a study path, allowing write operations for the remainder of the current R session. On Unix-like systems, also restores write permissions on cached study directories.
unlock_study(study_path)
study_path |
Path to the study folder |
Logical indicating success, invisibly
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.